ModifiedIO (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

## org.openqa.selenium.server
Class ModifiedIO

    java.lang.Object
      org.openqa.selenium.server.ModifiedIO

    public class ModifiedIO

extends java.lang.Object

Constructor Summary
`ModifiedIO()`

Method Summary
`static long` | `copy(java.io.InputStream in, java.io.OutputStream out)` Copy Stream in to Stream out until EOF or exception.
`static long` | `copy(java.io.InputStream in, java.io.OutputStream out, long byteCount)` Copy Stream in to Stream for byteCount bytes or until EOF or exception.
`static long` | `copy(java.io.Reader in, java.io.Writer out)`
`static long` | `copy(java.io.Reader in, java.io.Writer out, long byteCount)` Copy Reader to Writer for byteCount bytes or until EOF or exception.

Methods inherited from class java.lang.Object
`clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait`

Constructor Detail

### ModifiedIO

    public ModifiedIO()

Method Detail

### copy

    public static long copy(java.io.InputStream in,
                            java.io.OutputStream out)
                     throws java.io.IOException

  Copy Stream in to Stream out until EOF or exception.

  Throws:
    `java.io.IOException`

### copy

    public static long copy(java.io.Reader in,
                            java.io.Writer out)
                     throws java.io.IOException

  Throws:
    `java.io.IOException`

### copy

    public static long copy(java.io.InputStream in,
                            java.io.OutputStream out,
                            long byteCount)
                     throws java.io.IOException

  Copy Stream in to Stream for byteCount bytes or until EOF or exception.

  Returns:
    Copied bytes count or -1 if no bytes were read *and* EOF was reached
  Throws:
    `java.io.IOException`

### copy

    public static long copy(java.io.Reader in,
                            java.io.Writer out,
                            long byteCount)
                     throws java.io.IOException

  Copy Reader to Writer for byteCount bytes or until EOF or exception.

  Throws:
    `java.io.IOException`

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

Copyright © 2009. All Rights Reserved.